@@ -10,9 +10,9 @@
 # ---------------------------------------------------------------------------------------------------------
 """
 import time
-import logging
 from enum import Enum
 from selenium import webdriver
+from selenium_helper.log import logger
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webelement import WebElement
 from selenium_helper.utils import get_current_datetime_int_str
@@ -20,8 +20,6 @@ from selenium_helper.dir import join_path, get_image_dir, get_log_dir
 from selenium.common.exceptions import NoSuchElementException, TimeoutException, ElementNotInteractableException, \
     ElementClickInterceptedException
 
-logger = logging.getLogger("root")
-
 
 class Locator(Enum):
     id = By.ID
