@@ -11,6 +11,7 @@
 """
 import re
 import json
+import time
 import random
 import hashlib
 import urllib.parse
@@ -30,6 +31,10 @@ def get_current_datetime_int_str() -> str:
     )
 
 
+def get_current_ct() -> int:
+    return int(time.time() * 1000)
+
+
 def is_later_than_current_time(time_str: str, seconds: int = 30, current_dt: str = None):
     # 将给定的时间字符串转换为 datetime 对象
     given_time = datetime.strptime(time_str, '%H:%M').time()
